Skip to main content Crate enc Copy item path Source Expand description  Data Encoding
data (enabled by default) — Provides traits & utilities for encoding data.
base-64 (enabled by default) — Provides support for base-64 encoded data.
hex (enabled by default) — Provides support for hexadecimal encoded data.
percent (enabled by default) — Provides support for URL percent encoded data.
 Value Encoding
value (enabled by default) — Provides traits & utilities for encoding values.
var-int (enabled by default) — Provides support for variable-length encoded integers.
 Default
default — All features are included by default.
 Full
full-data (enabled by default) — Includes all the data encoding features.
full-value (enabled by default) — Includes all the value encoding features.
full (enabled by default) — Includes all the data & value encoding features.
 Dev
dev — Provides utilities for testing encoding implementations.
base_64 hex percent test var_int impl_decode_from_read_by_prefix Implements the DecodeFromRead trait for the target_type by delegating it to the
DecodeFromReadPrefix::decode_from_read_prefix function on the same target_type. impl_decode_from_read_prefix_length_prefixed Implements of the DecodeFromReadPrefix trait for the target_type by using the
DecodeFromRead::decode_from_read_length_prefixed_with_first_byte function on the same
target_type. impl_encode_to_write_stack_buf Implements the EncodeToWrite trait for the target_type. Error An error processing encoded data. DecodeFromRead A value that can decode itself from a Read. DecodeFromReadPrefix A value that can decode itself from a Read prefix. Decoder Responsible for decoding binary data. EncodeToSlice A value that can encode itself to a slice. EncodeToWrite A value that can encode itself to a Write. EncodedLen A value with an encoded length. Encoder Responsible for encoding binary data. StringEncoder Responsible for encoding binary data as UTF-8 encoded text. Validator Responsible for validating encoded data. read_optional_byte Reads an optional byte from the Read. read_single_byte Reads a single byte from the Read.